# kmergenetyper (k-mer gene typer)

# Installation

kmergenetyper typer requires kma (>=1.4.0) to be installed and usable directly from path (i.e. $kma).
This can be done by installing kma from source or using conda:

`conda create -n kmergenetyper -f kmergenetyper.yml`

`conda activate kmergenetyper`

`pip install kmergenetyper`

# Usage

`kmergenetyper -h`
